@@ -20,12 +20,13 @@ from starlette.middleware.trustedhost import TrustedHostMiddleware
 from starlette.middleware.httpsredirect import HTTPSRedirectMiddleware
 from starlette.exceptions import HTTPException, ExceptionMiddleware
 from starlette.routing import NoMatchFound
+from jinja2 import Environment, FileSystemLoader
 
 from .types import WSGIApp
 from .utils import Singleton
 from .config import here, Config
 from .http.request import Request
-from .http.responses import FileResponse, TemplateResponse, Jinja2Templates
+from .http.responses import FileResponse, TemplateResponse
 from .http.background import (
     BackgroundTasks,
     after_response_tasks_var,
@@ -290,7 +291,9 @@ class Index(metaclass=Singleton):
         config = Config()
 
         self.indexfile = IndexFile("views", here, True)
-        self.templates = Jinja2Templates(config.TEMPLATES)
+        self.jinja_env = Environment(
+            loader=FileSystemLoader(config.TEMPLATES), enable_async=True
+        )
         self.lifespan = Lifespan(
             on_startup={
                 check_on_startup.__qualname__: check_on_startup,
@@ -423,7 +426,7 @@ class Index(metaclass=Singleton):
             assert route.startswith("/"), "prefix must be start with '/'"
             assert not route.endswith("/"), "prefix can't end with '/'"
         if app_type == "wsgi":
-            app = WSGIMiddleware(app)
+            app = WSGIMiddleware(typing.cast(WSGIApp, app))
         app = typing.cast(ASGIApp, app)
         self.mount_apps.append((route, app))
 
@@ -453,7 +456,7 @@ class Index(metaclass=Singleton):
                 if isinstance(app, WSGIMiddleware):
                     if scope["type"] != "http":
                         continue
-                subscope = copy.deepcopy(scope)
+                subscope = copy.copy(scope)
                 subscope["path"] = path[len(path_prefix) :]
                 subscope["root_path"] = root_path + path_prefix
                 try:
@@ -477,4 +480,5 @@ class Index(metaclass=Singleton):
             await self.lifespan(scope, receive, send)
 
     async def __call__(self, scope: Scope, receive: Receive, send: Send) -> None:
+        scope["app"] = self
         await self.asgiapp(scope, receive, send)
