@@ -1,4 +1,5 @@
 import typing
+import asyncio
 import functools
 from importlib import import_module
 
@@ -13,14 +14,14 @@ from starlette.responses import (
     StreamingResponse,
     FileResponse,
 )
-from starlette.templating import (
-    BackgroundTask,
-    _TemplateResponse,
-)
+from starlette.background import BackgroundTask
 
+from ..types import Scope, Receive, Send
 from ..utils import Singleton
 from ..config import Config
 
+from .request import HTTPConnection
+
 __all__ = [
     "automatic",
     "Response",
@@ -35,15 +36,10 @@ __all__ = [
 ]
 
 
-class Jinja2Templates:
-    def __init__(self, searchpath: typing.Union[str, typing.Iterable[str]]) -> None:
-        self.loader = jinja2.FileSystemLoader(searchpath)
-        self.env = jinja2.Environment(loader=self.loader, autoescape=True)
+class TemplateResponse(Response):
+    media_type = "text/html"
 
-    def get_template(self, name: str) -> jinja2.Template:
-        return self.env.get_template(name)
-
-    def TemplateResponse(
+    def __init__(
         self,
         name: str,
         context: dict,
@@ -51,30 +47,34 @@ class Jinja2Templates:
         headers: dict = None,
         media_type: str = None,
         background: BackgroundTask = None,
-    ) -> _TemplateResponse:
-        template = self.get_template(name)
-        return _TemplateResponse(
-            template,
-            context,
-            status_code=status_code,
-            headers=headers,
-            media_type=media_type,
-            background=background,
-        )
+    ):
+        if not (
+            "request" in context and isinstance(context["request"], HTTPConnection)
+        ):
+            raise ValueError('context must include "request".')
+        self.env: jinja2.Environment = context["request"].scope["app"].jinja_env
+        self.template = self.env.get_template(name)
+        self.context = context
+        super().__init__(None, status_code, headers, media_type, background)
 
+    async def __call__(self, scope: Scope, receive: Receive, send: Send) -> None:
+        if self.env.enable_async:  # type: ignore
+            content = await self.template.render_async(self.context)
+        else:
+            content = self.template.render(self.context)
+        self.body = self.render(content)
+        self.headers.setdefault("content-length", str(len(content)))
 
-def TemplateResponse(
-    name: str,
-    context: dict,
-    status_code: int = 200,
-    headers: dict = None,
-    media_type: str = None,
-    background: BackgroundTask = None,
-) -> _TemplateResponse:
-    app = getattr(import_module("..applications", __package__), "Index")()
-    return app.templates.TemplateResponse(
-        name, context, status_code, headers, media_type, background
-    )
+        extensions = self.context.get("request", {}).get("extensions", {})
+        if "http.response.template" in extensions:
+            await send(
+                {
+                    "type": "http.response.template",
+                    "template": self.template,
+                    "context": self.context,
+                }
+            )
+        await super().__call__(scope, receive, send)
 
 
 class YAMLResponse(Response):
