@@ -1,9 +1,7 @@
-from .functions import describe, partial
+from .functions import describe
 from .application import OpenAPI
-from . import models
 
 __all__ = [
     "describe",
     "OpenAPI",
-    "models",
 ]
