@@ -1,22 +1,33 @@
 import os
+import sys
 from copy import deepcopy
 from inspect import signature
-from typing import List, Dict, Any
+from typing import List, Dict, Any, Sequence
+
+if sys.version_info[:2] < (3, 8):
+    from typing_extensions import TypedDict
+else:
+    from typing import TypedDict
 
 from starlette.types import Scope, Receive, Send
 from starlette.endpoints import Request, Response
-from starlette.exceptions import HTTPException
+from starlette.routing import NoMatchFound
 
-from indexpy.responses import (
+from ..http.responses import (
     JSONResponse,
     YAMLResponse,
     HTMLResponse,
 )
-from indexpy.applications import Index, IndexFile
+from ..applications import Index, IndexFile
 
 from .schema import schema_parameters, schema_request_body, schema_response
 
 
+class Tag(TypedDict):
+    description: str
+    paths: Sequence[str]
+
+
 class OpenAPI:
     def __init__(
         self,
@@ -24,7 +35,7 @@ class OpenAPI:
         description: str,
         version: str,
         *,
-        tags: Dict[str, Any] = {},
+        tags: Dict[str, Tag] = {},
         template: str = "",
         media_type="yaml",
     ):
@@ -83,7 +94,6 @@ class OpenAPI:
     def _generate_method(
         self, viewclass: object, path: str, method: str
     ) -> Dict[str, Any]:
-        sig = signature(getattr(viewclass, method))
         result: Dict[str, Any] = {}
 
         doc = getattr(viewclass, method).__doc__
@@ -96,26 +106,14 @@ class OpenAPI:
                 }
             )
 
+        params = getattr(getattr(viewclass, method), "__params__", {})
         result["parameters"] = schema_parameters(
-            None,
-            sig.parameters.get("query").annotation  # type: ignore
-            if sig.parameters.get("query")
-            else None,
-            sig.parameters.get("header").annotation  # type: ignore
-            if sig.parameters.get("header")
-            else None,
-            sig.parameters.get("cookie").annotation  # type: ignore
-            if sig.parameters.get("cookie")
-            else None,
+            None, params.get("query"), params.get("header"), params.get("cookie"),
         )
         if not result["parameters"]:
             del result["parameters"]
 
-        result["requestBody"] = schema_request_body(
-            sig.parameters.get("body").annotation  # type: ignore
-            if sig.parameters.get("body")
-            else None
-        )
+        result["requestBody"] = schema_request_body(params.get("body"))
         if not result["requestBody"]:
             del result["requestBody"]
 
@@ -155,7 +153,7 @@ class OpenAPI:
 
     async def __call__(self, scope: Scope, receive: Receive, send: Send) -> None:
         if scope["type"] != "http" or scope["path"] not in ("/", "/get"):
-            raise HTTPException(404)
+            raise NoMatchFound()
         request = Request(scope, receive, send)
 
         if scope["path"] == "/get":
@@ -163,7 +161,7 @@ class OpenAPI:
         elif scope["path"] == "/":
             handler = getattr(self, "template")
         else:
-            raise HTTPException(404)
+            raise NoMatchFound()
         response = await handler(request)
         await response(scope, receive, send)
 
