@@ -1,10 +1,10 @@
 from copy import deepcopy
-from typing import Any, List, Dict, Optional, Iterable, Mapping, Union
+from typing import Any, List, Dict, Optional, Iterable, Union, Sequence
 
 import yaml
+from pydantic import BaseModel
 
 from .types import File
-from .models import Model
 
 
 def replace_definitions(schema: Dict[str, Any]) -> Dict[str, Any]:
@@ -15,33 +15,35 @@ def replace_definitions(schema: Dict[str, Any]) -> Dict[str, Any]:
 
     if schema.get("definitions") is not None:
 
-        def replace(mapping: Dict[str, Any]) -> None:
-            for _name in mapping.keys():
-                if _name == "$ref":
-                    define_schema = schema
-                    for key in mapping["$ref"][2:].split("/"):
-                        define_schema = define_schema[key]
-                    break
-                elif isinstance(mapping[_name], Mapping):
-                    replace(mapping[_name])
-                elif isinstance(mapping[_name], Iterable) and not isinstance(
-                    mapping[_name], str
-                ):
-                    for value in mapping[_name]:
-                        replace(value)
-            else:
+        def replace(value: Union[str, Sequence[Any], Dict[str, Any]]) -> None:
+            if isinstance(value, str):
                 return
-            # replace ref and del it
-            mapping.update(define_schema)
-            del mapping["$ref"]
+            elif isinstance(value, Sequence):
+                for _value in value:
+                    replace(_value)
+            elif isinstance(value, Dict):
+                for _name in tuple(value.keys()):
+                    if _name == "$ref":
+                        define_schema = schema
+                        for key in value["$ref"][2:].split("/"):
+                            define_schema = define_schema[key]
+                        # replace ref and del it
+                        value.update(define_schema)
+                        del value["$ref"]
+                    elif isinstance(value[_name], Dict):
+                        replace(value[_name])
+                    elif isinstance(value[_name], Sequence):
+                        for _value in value[_name]:
+                            replace(_value)
 
+        replace(schema["definitions"])
         replace(schema["properties"])
         del schema["definitions"]
 
     return schema
 
 
-def schema_parameter(m: Optional[Model], position: str) -> List[Dict[str, Any]]:
+def schema_parameter(m: Optional[BaseModel], position: str) -> List[Dict[str, Any]]:
     """
     position: "path", "query", "header", "cookie"
     """
@@ -66,7 +68,10 @@ def schema_parameter(m: Optional[Model], position: str) -> List[Dict[str, Any]]:
 
 
 def schema_parameters(
-    path: Model = None, query: Model = None, header: Model = None, cookie: Model = None,
+    path: BaseModel = None,
+    query: BaseModel = None,
+    header: BaseModel = None,
+    cookie: BaseModel = None,
 ) -> List[Dict[str, Any]]:
 
     return (
@@ -77,7 +82,7 @@ def schema_parameters(
     )
 
 
-def schema_request_body(body: Model = None) -> Optional[Dict[str, Any]]:
+def schema_request_body(body: BaseModel = None) -> Optional[Dict[str, Any]]:
     if body is None:
         return None
 
@@ -96,7 +101,7 @@ def schema_request_body(body: Model = None) -> Optional[Dict[str, Any]]:
     }
 
 
-def schema_response(model: Union[Model, str]) -> Dict[str, Any]:
+def schema_response(model: Union[BaseModel, str]) -> Dict[str, Any]:
     if isinstance(model, str):
         return yaml.safe_load(model.strip())
     return {"application/json": {"schema": replace_definitions(model.schema())}}
